# Slither API

Slither is fully customizable:

- [Static Analysis](./static_analysis.md): learn about the basics of static analysis
- [API](./api.md)
- [SlithIR](./SlithIR.md)
- [SSA](./SlithIR-SSA.md)
- [Data dependency](./Data-dependency.md)
- [JSON output](./JSON-output.md)
